;; Generated package description from poke-mode.el  -*- no-byte-compile: t -*-
(define-package "poke-mode" "0.0.20230111.12941" "Major mode for editing Poke programs" 'nil :commit "9911440ba9517809dd2d2317f4b4ff9635adec78" :url "https://elpa.gnu.org/packages/poke-mode.html" :authors '(("Aurelien Aptel" . "aaptel@suse.com")) :maintainer '("Jose E. Marchesi" . "jemarch@gnu.org"))
